@@ -20,7 +20,7 @@ class RustSocket:
         self.steamid = steamid
         self.playertoken = playertoken
 
-    def __str__(self) -> str:
+    def __repr__(self) -> str:
         return "RustSocket: ip = {} | port = {} | steamid = {} | playertoken = {}".format(self.ip, self.port, self.steamid, self.playertoken)
 
     def __initProto(self) -> AppRequest:
